#
# spec file for package wxWidgets-wxcontainer
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           wxWidgets-wxcontainer
# Build flags are deduced from the package name and the repository environment:
#
# Flags deduced from the package name:
# If the Name tag contains "ansi", then compatibility ANSI version of wxString will be used.
# If the Name tag contains "wxcontainer", then old wx container API will be used instead of STL.
# If the Name tag contains "24c", then 2.4 compatibility API will be turned on.
#
# Flags inherited from the environment:
# If the WX_DEBUG is set and equal to 1, then debug versions of
# libraries with lots of asserts will be built. Debug version is useful
# for debugging of wxWidgets use.
#
# Note: "ansi" implies "wxcontainer" (STL was introduced much later than Unicode support).
%define base_name wxWidgets
# Tarball name:
# In theory, you can save some space and use wxGTK here. But current
# wxGTK tarballs lack sources for mmedia library, so we have to use
# full wxWidgets tarball here.
%define tarball_name wxWidgets
# Ancient applications that expect wxString being equal to char* may still need ANSI version:
%define ENABLE_UNICODE %(echo %{name} | grep -q ansi ; echo $?)
# STL is recommended by developers but break some packages (bnc#530027) and ABI compatibility:
%define ENABLE_STL %(echo %{name} | grep -q wxcontainer ; echo $?)
# --enable-compat24 breaks ABI compatibility and needs separate variant (bnc#660438):
%define ENABLE_COMPAT24 %(echo %{name} | grep -v -q 24c ; echo $?)
%if ! %ENABLE_UNICODE
%define ENABLE_STL 0
%endif
Version:        2.8.12
Release:        3.1
%define wx_minor %(echo %{version} | sed 's/\.[0-9][0-9]*$//')
%define wx_minor_description %{wx_minor}
# libdir for installing of all the stuff
%if %ENABLE_STL
%define _wxlibdir %{_libdir}/wx-%{wx_minor}-stl
%define _wx_variant stl
%define __wx_description STL API
%else
%define _wxlibdir %{_libdir}/wx-%{wx_minor}-wxcontainer
%define _wx_variant wxcontainer
%define __wx_description wx container API
%endif
%if %ENABLE_UNICODE
%define _wx_description %{__wx_description} with Unicode support
%else
%define _wx_description %{__wx_description} with ANSI wxString
%endif
%if %ENABLE_COMPAT24
%define wxlibdir %{_wxlibdir}24c
%define wx_variant %{_wx_variant}24c
%define wx_description %{_wx_description} and 2.4 compatibility
%else
%define wxlibdir %{_wxlibdir}
%define wx_variant %{_wx_variant}
%define wx_description %{_wx_description}
%endif
%if %ENABLE_UNICODE
%if 0%{?WX_DEBUG}
%define WXFLAGS ud
%else
%define WXFLAGS u
%endif
%else
%if 0%{?WX_DEBUG}
%define WXFLAGS d
%else
%define WXFLAGS %{nil}
%endif
%endif
# lang packages are exactly equal for all variants. Build it only once:
%if "%{name}" == "%{base_name}"
%define BUILD_LANG 1
%else
%define BUILD_LANG 0
%endif
Summary:        C++ Library for Cross-Platform Development
License:        GPL-2.0+
Group:          System/Libraries
Url:            http://www.wxwidgets.org/

Source:         %{tarball_name}-%{version}.tar.bz2
Source1:        README.SUSE
Source2:        virtual-package.README
Source3:        wxWidgets-find-wx-provides
Source4:        wxWidgets-find-wx-requires
Source5:        wxWidgets-rpmlintrc
# This script is not used during build, but it makes possible to
# identify and backport wxPython fixes to wxWidgets.
Source6:        wxpython-mkdiff.sh
Patch0:         wxGTK-2.6.3.3-decl.patch
Patch1:         wxGTK-enable-wxrc.patch
# PATCH-FEATURE-OPENSUSE wxWidgets-config-force-rpath.patch sbrabec@suse.cz -- Force rpath use for installed libraries.
Patch2:         wxWidgets-config-force-rpath.patch
# PATCH-FIX-OPENSUSE wxGTK-datarootdir.patch sbrabec@suse.cz -- Fix build error.
Patch3:         wxGTK-datarootdir.patch
# PATCH-FEATURE-OPENSUSE wxWidgets-find-wx-provides-bash3.patch sbrabec@suse.cz -- Port to bash-3 that does not support coproc.
Patch4:         wxWidgets-find-wx-provides-bash3.patch
# PATCH-FIX-UPSTREAM wxWidgets-to-wxpython-2.8.12.1.patch sbrabec@suse.cz -- wxPython changes backport.
Patch5:         wxWidgets-to-wxpython-2.8.12.1.patch
# PATCH-FIX-UPSTREAM <dan@danny.cz> FTBFS gcc6: narrowing conversion from int to char inside {}
Patch6:         wxWidgets-2.8.12-gcc6.patch
Patch7:         wxWidgets.uname.patch
Source50:       baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  SDL-devel
BuildRequires:  autoconf
BuildRequires:  cppunit-devel
BuildRequires:  gcc-c++
BuildRequires:  gconf2-devel
BuildRequires:  gnome-vfs2-devel
BuildRequires:  gtk2-devel
%if 0%?suse_version > 1230
BuildRequires:  libXinerama-devel
BuildRequires:  libXt-devel
%endif
BuildRequires:  libexpat-devel
BuildRequires:  libmspack-devel
BuildRequires:  libtiff-devel
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(libjpeg)
# We cannot use standard Requires/Provides, as we can have several instances of the library with the same soname.
%define _use_internal_dependency_generator 0

%description
wxWidgets is a free C++ library for cross-platform GUI.
With wxWidgets, you can create applications for different GUIs (GTK+,
Motif, MS Windows, MacOS X, Windows CE, GPE) from the same source code.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_base%{WXFLAGS}-2_8-0-%{wx_variant}
Summary:        wxWidgets Library
Group:          System/Libraries
# Name up to openSUSE 11.3 and up to wxGTK-2.8:
Obsoletes:      wxGTK <= %{version}.0
# Third party base package name:
Obsoletes:      wxWidgets < %{version}
# wxWidgets-lang requires wxWidgets. Provide them to fix dependencies:
Provides:       wxWidgets = %{version}
Recommends:     %{base_name}-lang >= %{version}

%description -n libwx_base%{WXFLAGS}-2_8-0-%{wx_variant}
Library for the wxWidgets cross-platform GUI.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_base%{WXFLAGS}_net-2_8-0-%{wx_variant}
Summary:        wxWidgets Library
Group:          System/Libraries

%description -n libwx_base%{WXFLAGS}_net-2_8-0-%{wx_variant}
Library for the wxWidgets cross-platform GUI.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_base%{WXFLAGS}_xml-2_8-0-%{wx_variant}
Summary:        wxWidgets Library
Group:          System/Libraries

%description -n libwx_base%{WXFLAGS}_xml-2_8-0-%{wx_variant}
Library for the wxWidgets cross-platform GUI.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_adv-2_8-0-%{wx_variant}
Summary:        wxWidgets Library
Group:          System/Libraries

%description -n libwx_gtk2%{WXFLAGS}_adv-2_8-0-%{wx_variant}
Library for the wxWidgets cross-platform GUI.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_aui-2_8-0-%{wx_variant}
Summary:        wxWidgets Library
Group:          System/Libraries

%description -n libwx_gtk2%{WXFLAGS}_aui-2_8-0-%{wx_variant}
Library for the wxWidgets cross-platform GUI.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_core-2_8-0-%{wx_variant}
Summary:        wxWidgets Library
Group:          System/Libraries

%description -n libwx_gtk2%{WXFLAGS}_core-2_8-0-%{wx_variant}
Library for the wxWidgets cross-platform GUI.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_gizmos-2_8-0-%{wx_variant}
Summary:        wxWidgets Library
Group:          System/Libraries

%description -n libwx_gtk2%{WXFLAGS}_gizmos-2_8-0-%{wx_variant}
Library for the wxWidgets cross-platform GUI.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_gizmos_xrc-2_8-0-%{wx_variant}
Summary:        wxWidgets Library
Group:          System/Libraries

%description -n libwx_gtk2%{WXFLAGS}_gizmos_xrc-2_8-0-%{wx_variant}
Library for the wxWidgets cross-platform GUI.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_gl-2_8-0-%{wx_variant}
Summary:        wxWidgets Library
Group:          System/Libraries

%description -n libwx_gtk2%{WXFLAGS}_gl-2_8-0-%{wx_variant}
Library for the wxWidgets cross-platform GUI.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_html-2_8-0-%{wx_variant}
Summary:        wxWidgets Library
Group:          System/Libraries

%description -n libwx_gtk2%{WXFLAGS}_html-2_8-0-%{wx_variant}
Library for the wxWidgets cross-platform GUI.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_mmedia-2_8-0-%{wx_variant}
Summary:        wxWidgets Library
Group:          System/Libraries

%description -n libwx_gtk2%{WXFLAGS}_mmedia-2_8-0-%{wx_variant}
Library for the wxWidgets cross-platform GUI.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_plot-2_8-0-%{wx_variant}
Summary:        wxWidgets Library
Group:          System/Libraries

%description -n libwx_gtk2%{WXFLAGS}_plot-2_8-0-%{wx_variant}
Library for the wxWidgets cross-platform GUI.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_qa-2_8-0-%{wx_variant}
Summary:        wxWidgets Library
Group:          System/Libraries

%description -n libwx_gtk2%{WXFLAGS}_qa-2_8-0-%{wx_variant}
Library for the wxWidgets cross-platform GUI.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_richtext-2_8-0-%{wx_variant}
Summary:        wxWidgets Library
Group:          System/Libraries

%description -n libwx_gtk2%{WXFLAGS}_richtext-2_8-0-%{wx_variant}
Library for the wxWidgets cross-platform GUI.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_stc-2_8-0-%{wx_variant}
Summary:        wxWidgets Library
Group:          System/Libraries

%description -n libwx_gtk2%{WXFLAGS}_stc-2_8-0-%{wx_variant}
Library for the wxWidgets cross-platform GUI.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_svg-2_8-0-%{wx_variant}
Summary:        wxWidgets Library
Group:          System/Libraries

%description -n libwx_gtk2%{WXFLAGS}_svg-2_8-0-%{wx_variant}
Library for the wxWidgets cross-platform GUI.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_xrc-2_8-0-%{wx_variant}
Summary:        wxWidgets Library
Group:          System/Libraries

%description -n libwx_gtk2%{WXFLAGS}_xrc-2_8-0-%{wx_variant}
Library for the wxWidgets cross-platform GUI.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%if ! %ENABLE_STL
%package -n libwx_gtk2%{WXFLAGS}_fl-2_8-0-%{wx_variant}
# This deprecated library does not compile with STL.
Summary:        wxWidgets Library
Group:          System/Libraries

%description -n libwx_gtk2%{WXFLAGS}_fl-2_8-0-%{wx_variant}
Library for the wxWidgets cross-platform GUI.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_ogl-2_8-0-%{wx_variant}
# This deprecated library does not compile with STL.
Summary:        wxWidgets Library
Group:          System/Libraries

%description -n libwx_gtk2%{WXFLAGS}_ogl-2_8-0-%{wx_variant}
Library for the wxWidgets cross-platform GUI.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%endif
%package plugin-sound_sdl%{WXFLAGS}-2_8-%{wx_variant}
Summary:        wxWidgets SDL Plugin
Group:          System/Libraries

%description plugin-sound_sdl%{WXFLAGS}-2_8-%{wx_variant}
SDL Plugin for the wxWidgets cross-platform GUI.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package compat-lib-config
Summary:        wxWidgets Library Compatibility Configuration
Group:          System/Libraries
Provides:       %{base_name}-ld_so_conf
Conflicts:      otherproviders(%{base_name}-ld_so_conf)
# For upgrade from openSUSE-12.1 (block possible non-conflicting downgrade of wxWidgets-compat-lib-config)
Conflicts:      wxWidgets-compat-lib-config < 2.8.12-12

%description compat-lib-config
This package contains a ld.so configuration file that allows to use third party
binaries with one of available instances of the wxWidgets libraries.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

Note: compat-lib-config variant packages are mutually exclusive. If you
need more instances at once, break RPM dependencies and use
LD_LIBRARY_PATH wrappers for those "broken" packages.

Available ABI variants:

default = stl:  API compatible with modern applications, ABI compatible with wxGTK in openSUSE == 11.1

wxcontainer:    API compatible with older applications, ABI compatible with wxGTK in openSUSE <= 11.3 except 11.1

wxcontainer24c: API compatible with old applications since since version 2.4, ABI compatible with Fedora

ansi:           API compatible with historical applications expecting 8-bit characters

%if %ENABLE_UNICODE && !%ENABLE_STL && %ENABLE_COMPAT24
%package -n wxWidgets-fedora-compat-lib-config
Summary:        wxWidgets Library Compatibility Configuration for Fedora Packages
Group:          System/Libraries
Provides:       %{base_name}-ld_so_conf
Conflicts:      otherproviders(%{base_name}-ld_so_conf)
# For upgrade from openSUSE-12.1 (block possible non-conflicting downgrade of wxWidgets-compat-lib-config)
Conflicts:      wxWidgets-compat-lib-config < 2.8.12-12

%description -n wxWidgets-fedora-compat-lib-config
This package contains a ld.so configuration file that allows to use Fedora
binaries with one of available instances of the wxWidgets libraries.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

This package is exactly equal to
wxWidgets-wxcontainer24c-compat-lib-config package, but this one will
follow Fedora configuration.

Note: compat-lib-config variant packages are mutually exclusive. If you
need more instances at once, break RPM dependencies and use
LD_LIBRARY_PATH wrappers for those "broken" packages.

Available ABI variants:

default = stl:  API compatible with modern applications, ABI compatible with wxGTK in openSUSE == 11.1

wxcontainer:    API compatible with older applications, ABI compatible with wxGTK in openSUSE <= 11.3 except 11.1

wxcontainer24c: API compatible with old applications since since version 2.4, ABI compatible with Fedora

ansi:           API compatible with historical applications expecting 8-bit characters

%endif
%package -n libwx_base%{WXFLAGS}-2_8-0-compat-lib-%{wx_variant}
Summary:        wxWidgets Library Compatibility Virtual Package
Group:          System/Libraries
Requires:       %{name}-compat-lib-config = %{version}
Requires:       libwx_base%{WXFLAGS}-2_8-0-%{wx_variant} = %{version}

%description -n libwx_base%{WXFLAGS}-2_8-0-compat-lib-%{wx_variant}
This virtual package contains symbols that allows to install third party
packages using wxWidgets libraries.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_base%{WXFLAGS}_net-2_8-0-compat-lib-%{wx_variant}
Summary:        wxWidgets Library Compatibility Virtual Package
Group:          System/Libraries
Requires:       %{name}-compat-lib-config = %{version}
Requires:       libwx_base%{WXFLAGS}_net-2_8-0-%{wx_variant} = %{version}

%description -n libwx_base%{WXFLAGS}_net-2_8-0-compat-lib-%{wx_variant}
This virtual package contains symbols that allows to install third party
packages using wxWidgets libraries.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_base%{WXFLAGS}_xml-2_8-0-compat-lib-%{wx_variant}
Summary:        wxWidgets Library Compatibility Virtual Package
Group:          System/Libraries
Requires:       %{name}-compat-lib-config = %{version}
Requires:       libwx_base%{WXFLAGS}_xml-2_8-0-%{wx_variant} = %{version}

%description -n libwx_base%{WXFLAGS}_xml-2_8-0-compat-lib-%{wx_variant}
This virtual package contains symbols that allows to install third party
packages using wxWidgets libraries.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_adv-2_8-0-compat-lib-%{wx_variant}
Summary:        wxWidgets Library Compatibility Virtual Package
Group:          System/Libraries
Requires:       %{name}-compat-lib-config = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_adv-2_8-0-%{wx_variant} = %{version}

%description -n libwx_gtk2%{WXFLAGS}_adv-2_8-0-compat-lib-%{wx_variant}
This virtual package contains symbols that allows to install third party
packages using wxWidgets libraries.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_aui-2_8-0-compat-lib-%{wx_variant}
Summary:        wxWidgets Library Compatibility Virtual Package
Group:          System/Libraries
Requires:       %{name}-compat-lib-config = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_aui-2_8-0-%{wx_variant} = %{version}

%description -n libwx_gtk2%{WXFLAGS}_aui-2_8-0-compat-lib-%{wx_variant}
This virtual package contains symbols that allows to install third party
packages using wxWidgets libraries.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_core-2_8-0-compat-lib-%{wx_variant}
Summary:        wxWidgets Library Compatibility Virtual Package
Group:          System/Libraries
Requires:       %{name}-compat-lib-config = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_core-2_8-0-%{wx_variant} = %{version}

%description -n libwx_gtk2%{WXFLAGS}_core-2_8-0-compat-lib-%{wx_variant}
This virtual package contains symbols that allows to install third party
packages using wxWidgets libraries.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_gizmos-2_8-0-compat-lib-%{wx_variant}
Summary:        wxWidgets Library Compatibility Virtual Package
Group:          System/Libraries
Requires:       %{name}-compat-lib-config = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_gizmos-2_8-0-%{wx_variant} = %{version}

%description -n libwx_gtk2%{WXFLAGS}_gizmos-2_8-0-compat-lib-%{wx_variant}
This virtual package contains symbols that allows to install third party
packages using wxWidgets libraries.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_gizmos_xrc-2_8-0-compat-lib-%{wx_variant}
Summary:        wxWidgets Library Compatibility Virtual Package
Group:          System/Libraries
Requires:       %{name}-compat-lib-config = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_gizmos_xrc-2_8-0-%{wx_variant} = %{version}

%description -n libwx_gtk2%{WXFLAGS}_gizmos_xrc-2_8-0-compat-lib-%{wx_variant}
This virtual package contains symbols that allows to install third party
packages using wxWidgets libraries.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_gl-2_8-0-compat-lib-%{wx_variant}
Summary:        wxWidgets Library Compatibility Virtual Package
Group:          System/Libraries
Requires:       %{name}-compat-lib-config = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_gl-2_8-0-%{wx_variant} = %{version}

%description -n libwx_gtk2%{WXFLAGS}_gl-2_8-0-compat-lib-%{wx_variant}
This virtual package contains symbols that allows to install third party
packages using wxWidgets libraries.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_html-2_8-0-compat-lib-%{wx_variant}
Summary:        wxWidgets Library Compatibility Virtual Package
Group:          System/Libraries
Requires:       %{name}-compat-lib-config = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_html-2_8-0-%{wx_variant} = %{version}

%description -n libwx_gtk2%{WXFLAGS}_html-2_8-0-compat-lib-%{wx_variant}
This virtual package contains symbols that allows to install third party
packages using wxWidgets libraries.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_mmedia-2_8-0-compat-lib-%{wx_variant}
Summary:        wxWidgets Library Compatibility Virtual Package
Group:          System/Libraries
Requires:       %{name}-compat-lib-config = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_mmedia-2_8-0-%{wx_variant} = %{version}

%description -n libwx_gtk2%{WXFLAGS}_mmedia-2_8-0-compat-lib-%{wx_variant}
This virtual package contains symbols that allows to install third party
packages using wxWidgets libraries.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_plot-2_8-0-compat-lib-%{wx_variant}
Summary:        wxWidgets Library Compatibility Virtual Package
Group:          System/Libraries
Requires:       %{name}-compat-lib-config = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_plot-2_8-0-%{wx_variant} = %{version}

%description -n libwx_gtk2%{WXFLAGS}_plot-2_8-0-compat-lib-%{wx_variant}
This virtual package contains symbols that allows to install third party
packages using wxWidgets libraries.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_qa-2_8-0-compat-lib-%{wx_variant}
Summary:        wxWidgets Library Compatibility Virtual Package
Group:          System/Libraries
Requires:       %{name}-compat-lib-config = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_qa-2_8-0-%{wx_variant} = %{version}

%description -n libwx_gtk2%{WXFLAGS}_qa-2_8-0-compat-lib-%{wx_variant}
This virtual package contains symbols that allows to install third party
packages using wxWidgets libraries.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_richtext-2_8-0-compat-lib-%{wx_variant}
Summary:        wxWidgets Library Compatibility Virtual Package
Group:          System/Libraries
Requires:       %{name}-compat-lib-config = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_richtext-2_8-0-%{wx_variant} = %{version}

%description -n libwx_gtk2%{WXFLAGS}_richtext-2_8-0-compat-lib-%{wx_variant}
This virtual package contains symbols that allows to install third party
packages using wxWidgets libraries.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_stc-2_8-0-compat-lib-%{wx_variant}
Summary:        wxWidgets Library Compatibility Virtual Package
Group:          System/Libraries
Requires:       %{name}-compat-lib-config = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_stc-2_8-0-%{wx_variant} = %{version}

%description -n libwx_gtk2%{WXFLAGS}_stc-2_8-0-compat-lib-%{wx_variant}
This virtual package contains symbols that allows to install third party
packages using wxWidgets libraries.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_svg-2_8-0-compat-lib-%{wx_variant}
Summary:        wxWidgets Library Compatibility Virtual Package
Group:          System/Libraries
Requires:       %{name}-compat-lib-config = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_svg-2_8-0-%{wx_variant} = %{version}

%description -n libwx_gtk2%{WXFLAGS}_svg-2_8-0-compat-lib-%{wx_variant}
This virtual package contains symbols that allows to install third party
packages using wxWidgets libraries.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_xrc-2_8-0-compat-lib-%{wx_variant}
Summary:        wxWidgets Library Compatibility Virtual Package
Group:          System/Libraries
Requires:       %{name}-compat-lib-config = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_xrc-2_8-0-%{wx_variant} = %{version}

%description -n libwx_gtk2%{WXFLAGS}_xrc-2_8-0-compat-lib-%{wx_variant}
This virtual package contains symbols that allows to install third party
packages using wxWidgets libraries.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%if ! %ENABLE_STL
%package -n libwx_gtk2%{WXFLAGS}_fl-2_8-0-compat-lib-%{wx_variant}
# This deprecated library does not compile with STL.
Summary:        wxWidgets Library Compatibility Virtual Package
Group:          System/Libraries
Requires:       %{name}-compat-lib-config = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_fl-2_8-0-%{wx_variant} = %{version}

%description -n libwx_gtk2%{WXFLAGS}_fl-2_8-0-compat-lib-%{wx_variant}
This virtual package contains symbols that allows to install third party
packages using wxWidgets libraries.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%package -n libwx_gtk2%{WXFLAGS}_ogl-2_8-0-compat-lib-%{wx_variant}
# This deprecated library does not compile with STL.
Summary:        wxWidgets Library Compatibility Virtual Package
Group:          System/Libraries
Requires:       %{name}-compat-lib-config = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_ogl-2_8-0-%{wx_variant} = %{version}

%description -n libwx_gtk2%{WXFLAGS}_ogl-2_8-0-compat-lib-%{wx_variant}
This virtual package contains symbols that allows to install third party
packages using wxWidgets libraries.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

%endif
%package devel
Summary:        Everything needed for development with wxWidgets
Group:          Development/Libraries/GNOME
Requires:       libwx_base%{WXFLAGS}-2_8-0-%{wx_variant} = %{version}
Requires:       libwx_base%{WXFLAGS}_net-2_8-0-%{wx_variant} = %{version}
Requires:       libwx_base%{WXFLAGS}_xml-2_8-0-%{wx_variant} = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_adv-2_8-0-%{wx_variant} = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_aui-2_8-0-%{wx_variant} = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_core-2_8-0-%{wx_variant} = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_gizmos-2_8-0-%{wx_variant} = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_gizmos_xrc-2_8-0-%{wx_variant} = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_gl-2_8-0-%{wx_variant} = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_html-2_8-0-%{wx_variant} = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_mmedia-2_8-0-%{wx_variant} = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_plot-2_8-0-%{wx_variant} = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_qa-2_8-0-%{wx_variant} = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_richtext-2_8-0-%{wx_variant} = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_stc-2_8-0-%{wx_variant} = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_svg-2_8-0-%{wx_variant} = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_xrc-2_8-0-%{wx_variant} = %{version}
%if ! %ENABLE_STL
Requires:       libwx_gtk2%{WXFLAGS}_fl-2_8-0-%{wx_variant} = %{version}
Requires:       libwx_gtk2%{WXFLAGS}_ogl-2_8-0-%{wx_variant} = %{version}
%endif
Requires:       gtk2-devel
Requires:       pkgconfig(gl)
Requires:       pkgconfig(glu)
Provides:       wxWidgets-devel = %{version}
Conflicts:      otherproviders(wxWidgets-devel)
# Name up to openSUSE 11.3 and up to wxGTK-2.8.x:
Provides:       wxGTK-devel = %{version}.0
Obsoletes:      wxGTK-devel <= %{version}.0

%description devel
wxWidgets is a free C++ library for cross-platform GUI development.
With wxWidgets, you can create applications for different GUIs (GTK+,
Motif, MS Windows, MacOS X, Windows CE, GPE) from the same source code.

This package contains all files needed for developing with wxGTK.

API version: %{wx_minor_description}
ABI variant: %{wx_description}

Note: wxWidgets variant devel packages are mutually exclusive. Please
read %{_docdir}/%{name}/README.SUSE to pick a correct variant.

%if %BUILD_LANG
%lang_package -n %{base_name}
%endif

%prep
echo "=== RPM build flags: WX_DEBUG=0%{?WX_DEBUG}, ENABLE_UNICODE=%{ENABLE_UNICODE}, ENABLE_STL=%{ENABLE_STL}, ENABLE_COMPAT24=%{ENABLE_COMPAT24}, WXFLAGS=%{WXFLAGS}, libdir=%{wxlibdir}, wx_variant=%{wx_variant}"
%setup -q -n %{tarball_name}-%{version}
%patch0
%patch1
%if "%{_libdir}" != "%{wxlibdir}"
# Apply this patch only if we are building outside libdir.
%patch2
%endif
%patch3
cp %{S:1} %{S:2} .
cp %{S:3} find-wx-provides
cp %{S:4} find-wx-requires
%if %suse_version < 1120
%patch4
%endif
%patch5 -p1
%patch6 -p1
%patch7 -p1
chmod +x find-wx-provides find-wx-requires
%if %ENABLE_STL
# Remove sources of deprecated libraries that don't compile with STL.
# The build failure would be ignored but the package will be rejected by
# QA checks due to errors in these directories.
rm contrib/src/{fl,ogl}/*.cpp
%endif

%build
rm -rfv src/expat
rm -rfv src/jpeg
rm -rfv src/png
rm -rfv src/tiff
rm -rfv src/zlib
# Ugly hack that makes possible to call autoconf:
sed -i 's/0\.2\.8/0.2.9/' build/aclocal/bakefile.m4
autoconf
# NOTE: gnome-vfs and gnomeprintui are deprecated. Disable it in future!
#
# STL and wx container versions of wxWidgets are binary incompatible,
# but they have equal names.  Starting with version 2.9.x, we are
# moving to STL by default. Libraries with support of the old wx
# containers will be packaged to a different libdir.
#
# We will enable 2.6.x compatibility together with disabling STL to
# decrease problems with old code.
#
# With 2.8.11:
# Work-around sound_sdl plugin PIC compilation error.
export CFLAGS="$RPM_OPT_FLAGS -DPIC -fPIC"
export CXXFLAGS="$RPM_OPT_FLAGS -DPIC -fPIC"
%if "%{_libdir}" != "%{wxlibdir}"
# One sub-library must be able to find another sub-library during the runtime.
export LDFLAGS="$LDFLAGS -Wl,-rpath,%{wxlibdir}"
%endif
# --enable-dataviewctrl does not compile
# --enable-prologio and --enable-resources: wxExpr and old-style resources are available in contrib only
# --enable-compat26 seems to disable 2.6 compatibility
# --disable-precomp-headers works only in 11.3 and newer
%configure\
	--libdir=%{wxlibdir}\
	--disable-static\
%if %ENABLE_UNICODE
	--enable-unicode\
%else
	--disable-unicode\
%endif
%if %ENABLE_COMPAT24
	--enable-compat24\
%else
	--disable-compat24\
%endif
	--with-opengl\
	--with-libmspack\
	--with-sdl\
	--with-gnomevfs\
	--enable-graphics_ctx\
	--enable-controls\
	--enable-iff\
	--enable-mediactrl\
	--enable-tabdialog\
	--enable-optimise\
%if 0%{?WX_DEBUG}
	--enable-debug\
%else
	--disable-debug\
%endif
%if %ENABLE_STL
	--enable-stl\
%else
	--disable-stl\
%endif
%if %suse_version < 1130
	--disable-precomp-headers\
%endif
	--enable-plugins
make %{?_smp_mflags}
make %{?_smp_mflags} -C contrib
%if %BUILD_LANG
cd locale
make allmo
cd ..
%endif

%install
make install DESTDIR="%buildroot"
make install DESTDIR="%buildroot" -C contrib

# Generate lang package only once for the main variant and recycle it everywhere.
%if %BUILD_LANG
# Locales for MS Windows:
rm -r $RPM_BUILD_ROOT%{_datadir}/locale/*/LC_MESSAGES/wxmsw.mo
%find_lang wxstd
%else
rm -rf $RPM_BUILD_ROOT%{_datadir}/locale
%endif

# Create synthetic .la files to work-around libtool inability to link
# third level libraries built on top of wxWidgets (bnc#690952).
cd $RPM_BUILD_ROOT%{wxlibdir}
for LIB in *.so ; do
	LIBNAME=${LIB%.so}
	LC_ALL=C
	LIBNAMES=($LIB*)
	unset LC_ALL
	cat >$LIBNAME.la <<EOF
# $LIBNAME.la - a libtool library file
# Generated by %{name}.spec (for GNU libtool)
#

# The name that we can dlopen(3).
dlname='${LIBNAMES[1]}'

# Names of this library.
library_names='$(for ((i=${#LIBNAMES[@]}-1;i>=0;i--)); do echo ${LIBNAMES[i]} ; done | tr \\n \  | sed s/\ $// )'

# The name of the static archive.
old_library=''

# Linker flags that can not go in dependency_libs.
inherited_linker_flags=' -pthread'

# Libraries that this one depends upon.
dependency_libs=''

# Names of additional weak libraries provided by this library
weak_library_names=''

# Version information for $LIBNAME.
current=8
age=0
revision=8

# Is this an already installed library?
installed=yes

# Should we warn about portability when linking against -modules?
shouldnotlink=no

# Files to dlopen/dlpreopen
dlopen=''
dlpreopen=''

# Directory that this library needs to be installed in:
libdir='%{wxlibdir}'
EOF
done
cd -

# Create ld.so.conf.d file that provides binary compatibility with third party binaries.
%if "%{_libdir}" != "%{wxlibdir}"
mkdir -p $RPM_BUILD_ROOT/etc/ld.so.conf.d
cat <<EOF >$RPM_BUILD_ROOT/etc/ld.so.conf.d/%{base_name}.conf
# Third party packages should search this directory for wxWidgets libraries.
#
# Don't modify this file, replace the wxWidgets-compat-lib package
# with another package instance instead.
#
%{wxlibdir}
EOF
%endif

# Create files that allow to create ABI-safe packages.
mkdir -p $RPM_BUILD_ROOT/etc/rpm
cat <<EOF >$RPM_BUILD_ROOT/etc/rpm/macros.wxWidgets
# This file is part of each wxWidgets-devel package instance and
# identifies the wxWidgets the variant the package is built with.
#
# Don't modify this file, replace the wxWidgets-devel package with
# another package instance instead.
#
# Please add following lines to all wxWidgets based package spec file
# preamble:
#
# %%define _use_internal_dependency_generator 0
# %%define __find_requires %%wx_requires
#
# and use this line if you build wxWidgets variant-specific libraries or
# modules
#
# %%define __find_provides %%wx_provides
#
%%wx_provides %{wxlibdir}/wx/rpm/find-wx-provides
%%wx_requires %{wxlibdir}/wx/rpm/find-wx-requires "%%{buildroot}"
EOF
mkdir -p $RPM_BUILD_ROOT%{wxlibdir}/wx/rpm
install find-wx-provides find-wx-requires $RPM_BUILD_ROOT%{wxlibdir}/wx/rpm/

# Modify provides/requires to prevent identical provides for different libraries.
%define build_wx_provides %{_builddir}/%{?buildsubdir}/build-wx-provides
%define build_find_wx_provides %{_builddir}/%{?buildsubdir}/find-wx-provides
%define build_wx_requires %{_builddir}/%{?buildsubdir}/find-wx-requires

# We need a very special version of %%wx_provides here.
# This version creates provides for compat-lib packages.
echo 0 >wx-libno
cat << EOF > %{build_wx_provides}
#! /bin/sh
# convert libfoo()() to libfoo(variant)()() and create virtual symbols.
wx_libno=\$(<$PWD/wx-libno)
# Trick: Package name is not passed to the script. Hopefully,
# processing order follows spec package order.
# Another possible solution: Deduce package name from the %%doc path.
wx_lib=(\
 libwx_base%{WXFLAGS}\
 libwx_base%{WXFLAGS}_net\
 libwx_base%{WXFLAGS}_xml\
 libwx_gtk2%{WXFLAGS}_adv\
 libwx_gtk2%{WXFLAGS}_aui\
 libwx_gtk2%{WXFLAGS}_core\
 libwx_gtk2%{WXFLAGS}_gizmos\
 libwx_gtk2%{WXFLAGS}_gizmos_xrc\
 libwx_gtk2%{WXFLAGS}_gl\
 libwx_gtk2%{WXFLAGS}_html\
 libwx_gtk2%{WXFLAGS}_mmedia\
 libwx_gtk2%{WXFLAGS}_plot\
 libwx_gtk2%{WXFLAGS}_qa\
 libwx_gtk2%{WXFLAGS}_richtext\
 libwx_gtk2%{WXFLAGS}_stc\
 libwx_gtk2%{WXFLAGS}_svg\
 libwx_gtk2%{WXFLAGS}_xrc\
%if ! %ENABLE_STL
 libwx_gtk2%{WXFLAGS}_fl\
 libwx_gtk2%{WXFLAGS}_ogl\
%endif
)

while read ; do
	case "\$REPLY" in
		*virtual-package.README )
			echo "\$REPLY" | /usr/lib/rpm/find-provides
			libname=\${wx_lib[\$wx_libno]}
			let wx_libno++
			echo \$wx_libno >$PWD/wx-libno
			# We don't know buildroot directory here. Strip known part of path to get it.
			ls -1 \${REPLY%%%{_docdir}/*/virtual-package.README}/%{wxlibdir}/* |
				grep -F \${libname}- |
				/usr/lib/rpm/find-provides
			;;
		*%{_docdir}* )
			echo "\$REPLY" | %{build_find_wx_provides}
			;;
		* )
			( echo "\$REPLY" ; cat ) | %{build_find_wx_provides}
			;;
	esac
done
EOF

chmod 755 %{build_wx_provides}
%define __find_provides %{build_wx_provides}
%define __find_requires %{build_wx_requires} "%{buildroot}"

%post compat-lib-config -p /sbin/ldconfig
%postun compat-lib-config -p /sbin/ldconfig
%triggerin compat-lib-config -- libwx_base%{WXFLAGS}-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerpostun compat-lib-config -- libwx_base%{WXFLAGS}-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerin compat-lib-config -- libwx_base%{WXFLAGS}_net-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerpostun compat-lib-config -- libwx_base%{WXFLAGS}_net-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerin compat-lib-config -- libwx_base%{WXFLAGS}_xml-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerpostun compat-lib-config -- libwx_base%{WXFLAGS}_xml-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerin compat-lib-config -- libwx_gtk2%{WXFLAGS}_adv-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerpostun compat-lib-config -- libwx_gtk2%{WXFLAGS}_adv-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerin compat-lib-config -- libwx_gtk2%{WXFLAGS}_aui-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerpostun compat-lib-config -- libwx_gtk2%{WXFLAGS}_aui-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerin compat-lib-config -- libwx_gtk2%{WXFLAGS}_core-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerpostun compat-lib-config -- libwx_gtk2%{WXFLAGS}_core-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerin compat-lib-config -- libwx_gtk2%{WXFLAGS}_gizmos-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerpostun compat-lib-config -- libwx_gtk2%{WXFLAGS}_gizmos-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerin compat-lib-config -- libwx_gtk2%{WXFLAGS}_gizmos_xrc-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerpostun compat-lib-config -- libwx_gtk2%{WXFLAGS}_gizmos_xrc-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerin compat-lib-config -- libwx_gtk2%{WXFLAGS}_gl-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerpostun compat-lib-config -- libwx_gtk2%{WXFLAGS}_gl-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerin compat-lib-config -- libwx_gtk2%{WXFLAGS}_html-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerpostun compat-lib-config -- libwx_gtk2%{WXFLAGS}_html-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerin compat-lib-config -- libwx_gtk2%{WXFLAGS}_mmedia-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerpostun compat-lib-config -- libwx_gtk2%{WXFLAGS}_mmedia-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerin compat-lib-config -- libwx_gtk2%{WXFLAGS}_plot-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerpostun compat-lib-config -- libwx_gtk2%{WXFLAGS}_plot-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerin compat-lib-config -- libwx_gtk2%{WXFLAGS}_qa-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerpostun compat-lib-config -- libwx_gtk2%{WXFLAGS}_qa-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerin compat-lib-config -- libwx_gtk2%{WXFLAGS}_richtext-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerpostun compat-lib-config -- libwx_gtk2%{WXFLAGS}_richtext-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerin compat-lib-config -- libwx_gtk2%{WXFLAGS}_stc-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerpostun compat-lib-config -- libwx_gtk2%{WXFLAGS}_stc-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerin compat-lib-config -- libwx_gtk2%{WXFLAGS}_svg-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerpostun compat-lib-config -- libwx_gtk2%{WXFLAGS}_svg-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerin compat-lib-config -- libwx_gtk2%{WXFLAGS}_xrc-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerpostun compat-lib-config -- libwx_gtk2%{WXFLAGS}_xrc-2_8-0-%{wx_variant}
/sbin/ldconfig
%if ! %ENABLE_STL
%triggerin compat-lib-config -- libwx_gtk2%{WXFLAGS}_fl-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerpostun compat-lib-config -- libwx_gtk2%{WXFLAGS}_fl-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerin compat-lib-config -- libwx_gtk2%{WXFLAGS}_ogl-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerpostun compat-lib-config -- libwx_gtk2%{WXFLAGS}_ogl-2_8-0-%{wx_variant}
/sbin/ldconfig
%endif
%if %ENABLE_UNICODE && !%ENABLE_STL && %ENABLE_COMPAT24
%triggerin -n wxWidgets-fedora-compat-lib-config -- libwx_gtk2%{WXFLAGS}_ogl-2_8-0-%{wx_variant}
/sbin/ldconfig

%triggerpostun -n wxWidgets-fedora-compat-lib-config -- libwx_gtk2%{WXFLAGS}_ogl-2_8-0-%{wx_variant}
/sbin/ldconfig
%endif

%if "%{_libdir}" == "%{wxlibdir}"
%post -n libwx_base%{WXFLAGS}-2_8-0-%{wx_variant} -p /sbin/ldconfig
%postun -n libwx_base%{WXFLAGS}-2_8-0-%{wx_variant} -p /sbin/ldconfig
%post -n libwx_base%{WXFLAGS}_net-2_8-0-%{wx_variant} -p /sbin/ldconfig
%postun -n libwx_base%{WXFLAGS}_net-2_8-0-%{wx_variant} -p /sbin/ldconfig
%post -n libwx_base%{WXFLAGS}_xml-2_8-0-%{wx_variant} -p /sbin/ldconfig
%postun -n libwx_base%{WXFLAGS}_xml-2_8-0-%{wx_variant} -p /sbin/ldconfig
%post -n libwx_gtk2%{WXFLAGS}_adv-2_8-0-%{wx_variant} -p /sbin/ldconfig
%postun -n libwx_gtk2%{WXFLAGS}_adv-2_8-0-%{wx_variant} -p /sbin/ldconfig
%post -n libwx_gtk2%{WXFLAGS}_aui-2_8-0-%{wx_variant} -p /sbin/ldconfig
%postun -n libwx_gtk2%{WXFLAGS}_aui-2_8-0-%{wx_variant} -p /sbin/ldconfig
%post -n libwx_gtk2%{WXFLAGS}_core-2_8-0-%{wx_variant} -p /sbin/ldconfig
%postun -n libwx_gtk2%{WXFLAGS}_core-2_8-0-%{wx_variant} -p /sbin/ldconfig
%post -n libwx_gtk2%{WXFLAGS}_gizmos-2_8-0-%{wx_variant} -p /sbin/ldconfig
%postun -n libwx_gtk2%{WXFLAGS}_gizmos-2_8-0-%{wx_variant} -p /sbin/ldconfig
%post -n libwx_gtk2%{WXFLAGS}_gizmos_xrc-2_8-0-%{wx_variant} -p /sbin/ldconfig
%postun -n libwx_gtk2%{WXFLAGS}_gizmos_xrc-2_8-0-%{wx_variant} -p /sbin/ldconfig
%post -n libwx_gtk2%{WXFLAGS}_gl-2_8-0-%{wx_variant} -p /sbin/ldconfig
%postun -n libwx_gtk2%{WXFLAGS}_gl-2_8-0-%{wx_variant} -p /sbin/ldconfig
%post -n libwx_gtk2%{WXFLAGS}_html-2_8-0-%{wx_variant} -p /sbin/ldconfig
%postun -n libwx_gtk2%{WXFLAGS}_html-2_8-0-%{wx_variant} -p /sbin/ldconfig
%post -n libwx_gtk2%{WXFLAGS}_mmedia-2_8-0-%{wx_variant} -p /sbin/ldconfig
%postun -n libwx_gtk2%{WXFLAGS}_mmedia-2_8-0-%{wx_variant} -p /sbin/ldconfig
%post -n libwx_gtk2%{WXFLAGS}_plot-2_8-0-%{wx_variant} -p /sbin/ldconfig
%postun -n libwx_gtk2%{WXFLAGS}_plot-2_8-0-%{wx_variant} -p /sbin/ldconfig
%post -n libwx_gtk2%{WXFLAGS}_qa-2_8-0-%{wx_variant} -p /sbin/ldconfig
%postun -n libwx_gtk2%{WXFLAGS}_qa-2_8-0-%{wx_variant} -p /sbin/ldconfig
%post -n libwx_gtk2%{WXFLAGS}_richtext-2_8-0-%{wx_variant} -p /sbin/ldconfig
%postun -n libwx_gtk2%{WXFLAGS}_richtext-2_8-0-%{wx_variant} -p /sbin/ldconfig
%post -n libwx_gtk2%{WXFLAGS}_stc-2_8-0-%{wx_variant} -p /sbin/ldconfig
%postun -n libwx_gtk2%{WXFLAGS}_stc-2_8-0-%{wx_variant} -p /sbin/ldconfig
%post -n libwx_gtk2%{WXFLAGS}_svg-2_8-0-%{wx_variant} -p /sbin/ldconfig
%postun -n libwx_gtk2%{WXFLAGS}_svg-2_8-0-%{wx_variant} -p /sbin/ldconfig
%post -n libwx_gtk2%{WXFLAGS}_xrc-2_8-0-%{wx_variant} -p /sbin/ldconfig
%postun -n libwx_gtk2%{WXFLAGS}_xrc-2_8-0-%{wx_variant} -p /sbin/ldconfig
%if ! %ENABLE_STL
%post -n libwx_gtk2%{WXFLAGS}_fl-2_8-0-%{wx_variant} -p /sbin/ldconfig
%postun -n libwx_gtk2%{WXFLAGS}_fl-2_8-0-%{wx_variant} -p /sbin/ldconfig
%post -n libwx_gtk2%{WXFLAGS}_ogl-2_8-0-%{wx_variant} -p /sbin/ldconfig
%postun -n libwx_gtk2%{WXFLAGS}_ogl-2_8-0-%{wx_variant} -p /sbin/ldconfig
%endif
%endif

%if %BUILD_LANG
%files lang -f wxstd.lang
%endif

%files -n libwx_base%{WXFLAGS}-2_8-0-%{wx_variant}
%defattr (-,root,root)
%{wxlibdir}/libwx_base%{WXFLAGS}-2.8.so.0*
%if "%{_libdir}" != "%{wxlibdir}"
%dir %{wxlibdir}
%endif
%dir %{wxlibdir}/wx
%dir %{wxlibdir}/wx/%{wx_minor}

%files -n libwx_base%{WXFLAGS}_net-2_8-0-%{wx_variant}
%defattr (-,root,root)
%{wxlibdir}/libwx_base%{WXFLAGS}_net-2.8.so.0*

%files -n libwx_base%{WXFLAGS}_xml-2_8-0-%{wx_variant}
%defattr (-,root,root)
%{wxlibdir}/libwx_base%{WXFLAGS}_xml-2.8.so.0*

%files -n libwx_gtk2%{WXFLAGS}_adv-2_8-0-%{wx_variant}
%defattr (-,root,root)
%{wxlibdir}/libwx_gtk2%{WXFLAGS}_adv-2.8.so.0*

%files -n libwx_gtk2%{WXFLAGS}_aui-2_8-0-%{wx_variant}
%defattr (-,root,root)
%{wxlibdir}/libwx_gtk2%{WXFLAGS}_aui-2.8.so.0*

%files -n libwx_gtk2%{WXFLAGS}_core-2_8-0-%{wx_variant}
%defattr (-,root,root)
%{wxlibdir}/libwx_gtk2%{WXFLAGS}_core-2.8.so.0*

%files -n libwx_gtk2%{WXFLAGS}_gizmos-2_8-0-%{wx_variant}
%defattr (-,root,root)
%{wxlibdir}/libwx_gtk2%{WXFLAGS}_gizmos-2.8.so.0*

%files -n libwx_gtk2%{WXFLAGS}_gizmos_xrc-2_8-0-%{wx_variant}
%defattr (-,root,root)
%{wxlibdir}/libwx_gtk2%{WXFLAGS}_gizmos_xrc-2.8.so.0*

%files -n libwx_gtk2%{WXFLAGS}_gl-2_8-0-%{wx_variant}
%defattr (-,root,root)
%{wxlibdir}/libwx_gtk2%{WXFLAGS}_gl-2.8.so.0*

%files -n libwx_gtk2%{WXFLAGS}_html-2_8-0-%{wx_variant}
%defattr (-,root,root)
%{wxlibdir}/libwx_gtk2%{WXFLAGS}_html-2.8.so.0*

%files -n libwx_gtk2%{WXFLAGS}_mmedia-2_8-0-%{wx_variant}
%defattr (-,root,root)
%{wxlibdir}/libwx_gtk2%{WXFLAGS}_mmedia-2.8.so.0*

%files -n libwx_gtk2%{WXFLAGS}_plot-2_8-0-%{wx_variant}
%defattr (-,root,root)
%{wxlibdir}/libwx_gtk2%{WXFLAGS}_plot-2.8.so.0*

%files -n libwx_gtk2%{WXFLAGS}_qa-2_8-0-%{wx_variant}
%defattr (-,root,root)
%{wxlibdir}/libwx_gtk2%{WXFLAGS}_qa-2.8.so.0*

%files -n libwx_gtk2%{WXFLAGS}_richtext-2_8-0-%{wx_variant}
%defattr (-,root,root)
%{wxlibdir}/libwx_gtk2%{WXFLAGS}_richtext-2.8.so.0*

%files -n libwx_gtk2%{WXFLAGS}_stc-2_8-0-%{wx_variant}
%defattr (-,root,root)
%{wxlibdir}/libwx_gtk2%{WXFLAGS}_stc-2.8.so.0*

%files -n libwx_gtk2%{WXFLAGS}_svg-2_8-0-%{wx_variant}
%defattr (-,root,root)
%{wxlibdir}/libwx_gtk2%{WXFLAGS}_svg-2.8.so.0*

%files -n libwx_gtk2%{WXFLAGS}_xrc-2_8-0-%{wx_variant}
%defattr (-,root,root)
%{wxlibdir}/libwx_gtk2%{WXFLAGS}_xrc-2.8.so.0*

%if ! %ENABLE_STL
%files -n libwx_gtk2%{WXFLAGS}_fl-2_8-0-%{wx_variant}
%defattr (-,root,root)
%{wxlibdir}/libwx_gtk2%{WXFLAGS}_fl-2.8.so.0*

%files -n libwx_gtk2%{WXFLAGS}_ogl-2_8-0-%{wx_variant}
%defattr (-,root,root)
%{wxlibdir}/libwx_gtk2%{WXFLAGS}_ogl-2.8.so.0*
%endif

%files plugin-sound_sdl%{WXFLAGS}-2_8-%{wx_variant}
%defattr (-,root,root)
%{wxlibdir}/wx/%{wx_minor}/sound_sdl%{WXFLAGS}-%{wx_minor}.so

%files compat-lib-config
%defattr (-,root,root)
/etc/ld.so.conf.d/%{base_name}.conf

%if %ENABLE_UNICODE && !%ENABLE_STL && %ENABLE_COMPAT24
%files -n wxWidgets-fedora-compat-lib-config
%defattr (-,root,root)
/etc/ld.so.conf.d/%{base_name}.conf
%endif

%files -n libwx_base%{WXFLAGS}-2_8-0-compat-lib-%{wx_variant}
%defattr (-,root,root)
%doc virtual-package.README

%files -n libwx_base%{WXFLAGS}_net-2_8-0-compat-lib-%{wx_variant}
%defattr (-,root,root)
%doc virtual-package.README

%files -n libwx_base%{WXFLAGS}_xml-2_8-0-compat-lib-%{wx_variant}
%defattr (-,root,root)
%doc virtual-package.README

%files -n libwx_gtk2%{WXFLAGS}_adv-2_8-0-compat-lib-%{wx_variant}
%defattr (-,root,root)
%doc virtual-package.README

%files -n libwx_gtk2%{WXFLAGS}_aui-2_8-0-compat-lib-%{wx_variant}
%defattr (-,root,root)
%doc virtual-package.README

%files -n libwx_gtk2%{WXFLAGS}_core-2_8-0-compat-lib-%{wx_variant}
%defattr (-,root,root)
%doc virtual-package.README

%files -n libwx_gtk2%{WXFLAGS}_gizmos-2_8-0-compat-lib-%{wx_variant}
%defattr (-,root,root)
%doc virtual-package.README

%files -n libwx_gtk2%{WXFLAGS}_gizmos_xrc-2_8-0-compat-lib-%{wx_variant}
%defattr (-,root,root)
%doc virtual-package.README

%files -n libwx_gtk2%{WXFLAGS}_gl-2_8-0-compat-lib-%{wx_variant}
%defattr (-,root,root)
%doc virtual-package.README

%files -n libwx_gtk2%{WXFLAGS}_html-2_8-0-compat-lib-%{wx_variant}
%defattr (-,root,root)
%doc virtual-package.README

%files -n libwx_gtk2%{WXFLAGS}_mmedia-2_8-0-compat-lib-%{wx_variant}
%defattr (-,root,root)
%doc virtual-package.README

%files -n libwx_gtk2%{WXFLAGS}_plot-2_8-0-compat-lib-%{wx_variant}
%defattr (-,root,root)
%doc virtual-package.README

%files -n libwx_gtk2%{WXFLAGS}_qa-2_8-0-compat-lib-%{wx_variant}
%defattr (-,root,root)
%doc virtual-package.README

%files -n libwx_gtk2%{WXFLAGS}_richtext-2_8-0-compat-lib-%{wx_variant}
%defattr (-,root,root)
%doc virtual-package.README

%files -n libwx_gtk2%{WXFLAGS}_stc-2_8-0-compat-lib-%{wx_variant}
%defattr (-,root,root)
%doc virtual-package.README

%files -n libwx_gtk2%{WXFLAGS}_svg-2_8-0-compat-lib-%{wx_variant}
%defattr (-,root,root)
%doc virtual-package.README

%files -n libwx_gtk2%{WXFLAGS}_xrc-2_8-0-compat-lib-%{wx_variant}
%defattr (-,root,root)
%doc virtual-package.README

%if ! %ENABLE_STL
%files -n libwx_gtk2%{WXFLAGS}_fl-2_8-0-compat-lib-%{wx_variant}
%defattr (-,root,root)
%doc virtual-package.README

%files -n libwx_gtk2%{WXFLAGS}_ogl-2_8-0-compat-lib-%{wx_variant}
%defattr (-,root,root)
%doc virtual-package.README
%endif

%files devel
%defattr (-,root,root)
# Complete documentation is available in the docs packages.
%doc docs/*.txt README.SUSE
%{_bindir}/wxrc
%{_bindir}/wxrc-%{wx_minor}
%{_bindir}/*-config*
%{_datadir}/aclocal
%{_datadir}/bakefile
%{_includedir}/wx-%{wx_minor}
%{wxlibdir}/*.so
%{wxlibdir}/*.la
%{wxlibdir}/wx/config
%{wxlibdir}/wx/include
%{wxlibdir}/wx/rpm
/etc/rpm/macros.wxWidgets

%changelog
* Sat Jun 18 2016 i@marguerite.su
- add patch: wxWidgets-2.8.12-gcc6.patch
  * fix FTBFS: gcc6 narrowing conversion from int to char inside {}
  * original patch from <dan@danny.cz> for fedora project
* Thu Jul 31 2014 dimstar@opensuse.org
- Rename rpmlintrc to %%{name}-rpmlintrc.
  Follow the packaging guidelines.
* Fri Apr  4 2014 seiler@b1-systems.de
- removed unneeded 32bit packages (*-compat-lib*) which has no libraries
* Mon Feb 17 2014 seiler@b1-systems.de
- added baselibs.conf to add *-32bit packages
* Thu Aug 22 2013 jengelh@inai.de
- Use %%_smp_mflags for parallel build and better make install call.
* Thu May 30 2013 sbrabec@suse.cz
- Add libXinerama-devel to BuildRequires (bnc#820016).
* Mon Apr 29 2013 mhrusecky@suse.com
- add libXt-devel buildrequires to fix Factory build
* Sun Mar 24 2013 jengelh@inai.de
- Update dependencies for wxWidgets-devel: Mesa no longer bundles GL
* Wed Oct 24 2012 sbrabec@suse.cz
- Add "API version" in %%description.
* Thu Sep 20 2012 coolo@suse.com
- add explicit buildrequire on pkgconfig(glu)
* Thu Apr 19 2012 sbrabec@suse.cz
- Added support for Fedora compatible 24c variants (bnc#660438).
- Change name of compat-lib-config virtual provide to not clash
  with package name, fix requires/provides generator (bnc#757124).
- Added wxPython fix backport.
* Wed Dec 21 2011 coolo@suse.com
- own aclocal directory, there is no other reason to buildrequire
  automake
* Wed Dec 21 2011 coolo@suse.com
- add autoconf as buildrequire to avoid implicit dependency
* Tue Dec 20 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Mon Oct 17 2011 coolo@suse.com
- fix whitespace of spec file
* Tue Jul 26 2011 aj@suse.de
- Recommend instead of require lang package.
* Tue May 17 2011 sbrabec@suse.cz
- Create synthetic .la files to work-around libtool failures when
  linking third level libraries or binaries (bnc#690952).
* Fri Apr  8 2011 sbrabec@suse.cz
- Updated to version 2.8.12:
  * Many crash and bug fixes.
  * Minor API improvements.
  * Several additions for forward compatibility with version 2.9.
  * See changes.txt for more.
* Fri Apr  8 2011 sbrabec@suse.cz
- Do not use bash coproc on system with bash-3.
* Tue Mar 29 2011 sbrabec@suse.cz
- Fixed find-wx-requires to check directories instead of library
  name. Provide find-wx-provides. (bnc#681409)
* Fri Mar  4 2011 sbrabec@suse.cz
- Fixed %%WX_DEBUG support.
* Tue Dec 21 2010 sbrabec@suse.cz
- Rename package to wxWidgets to follow upstream base name.
- Split wxPython documentation to a separate package.
- Support for build of Unicode and ANSI, standard and debug and STL
  and wxcontainer variants.
- Build wxWidgets variants separately.
- Spec file completely rewritten.
- Libraries moved from libdir to make possible to use binary
  incompatible variants. Use RPATH.
- Mangle rpm symbols to prevent ABI clash of binary incompatible
  variants with equal SONAME.
- Created virtually empty compatibility "libraries" to fulfill
  dependencies of third party packages.
- Provide rpm support macro %%wx_requires.
* Sun Aug 15 2010 termim@gmail.com
-  Updated to version 2.8.11.0
  Adds Python 2.7 builds, PySlices, new pubsub implementation,
  lots of updates to AGW, and lots of bugs fixed.
-  Removed wxGTK-GSocket-clash.patch and wxGTK-editra-ebmlib.patch
  as already fixed.
* Tue Jun 15 2010 sbrabec@suse.cz
- Added --enable-graphics_ctx to fix Editra (bnc#580060).
- Added ebmlib file required by Editra (bnc#580060,
  patch from Salix).
* Mon Feb 22 2010 crrodriguez@opensuse.org
- build with PIC
* Thu Jan 28 2010 sbrabec@suse.cz
- Enabled media libraries (bnc#565039).
* Fri Sep 25 2009 sbrabec@suse.cz
- Disabled STL (bnc#530027). See also
  http://lists.opensuse.org/opensuse-factory/2009-09/msg00386.html
- Removed obsolete RPATH.
- The GSocket symbol clash fix replaced by the upstream one.
* Thu Sep 17 2009 matejcik@suse.cz
- fixed pth file to point to platlib
* Sat Sep  5 2009 sbrabec@suse.cz
- Fixed for the latest python package.
* Fri Aug  7 2009 sbrabec@suse.cz
- Updated to version 2.8.10.1:
  * Incompatible change in wxTreeCtrl behaviour!
  * Added several functions forward compatible with wxWidgets 3.0.
  * Add wxBU_EXACTFIT support to wxToggleButton XRC handler.
  * wxHashMap::insert() doesn't update the value if it didn't
    insert the element any more.
  * Correct bug in wxTimeSpan::Format() for negative spans.
  * Correct several bugs in wxList using end() iterators.
  * Translation updates.
  * Fix wxURL::GetInputStream() for URLs with special characters in
    credentials.
  * Fix wxURI::GetUser() for URIs without password.
  * Correct wxDateTime DST computation for 2006 and later.
  * wxRTC: fixed a problem with HTML list generation.
  * wxRTC: no longer deletes a character when content is selected
  before pressing Delete.
  * wxRTC: fixed inability to select no superscript and no
  subscript in formatting dialog.
  * wxRTC: fixed centering and right-justification when combined
    with left indentation.
  * wxRTC: fixed lack of right margin when centering or
    right-justifying.
  * wxRTC: fixed wrong descent when wrapping lines with different
    font sizes.
  * wxRTC: fixed wrapping problem for long lines.
  * wxRTC: all buffer margins now respected.
  * wxRTC: Added wxRE_CENTRE_CARET to centre the caret line
    vertically.
  * Fixed wxHTML's pagebreaks computation in tables.
  * Fixed wxHtmlWindow::SelectionToText() to correctly insert
    newlines after single-cell paragraphs.
  * Fixed wxHTML's line breaks handling in <pre> blocks.
  * wxHTML: don't include extra whitespace in table cells.
  * Implemented wxWindow::DragAcceptFiles() on all platforms.
  * Added wxAUI_MGR_LIVE_RESIZE flag to wxAuiManager.
  * Use bitmap mask in wxSplashScreen.
  * Translate "(c)" and "(C)" to the real copyright sign in
    wxAboutBox.
  * Fix painting of highlight border for merged cells in wxGrid.
  * Fix handling of long lines in wxGridCellAutoWrapStringRenderer.
  * Return false from wxSingleInstanceChecker::IsAnotherRunning()
    if an error occurred while opening or reading the lock file.
  * Fixed printing to use fonts sizes adjustment consistent with
    wxMSW.
  * Make colours used by list, tree and status bar controls more
    consistent with the system theme settings.
  * Worked around bug in GTK+ < 2.14 where enabling some controls
    such as wxButton didn't re-enable sensitivity until the mouse
    was moved.
* Thu Jun 18 2009 sbrabec@suse.cz
- Worked-around GSocket name conflict with GIO.
* Tue Feb 17 2009 crrodriguez@suse.de
- build require libexpat-devel so we dont use the bundled one
* Wed Feb  4 2009 pth@suse.de
- Disable the use of precompiled headers as the way wxWidgets uses
  them is not supported by current GCC.
* Tue Feb  3 2009 pth@suse.de
- Update to 2.8.9.1:
  * Optimize wxString::Replace() for single character arguments.
  * Updated Hindi translation.
  * Use tr1::unordered_{map,set} for wxHash{Map,Set} implementation if available
    in STL build; in particular do not use deprecated hash_{map,set} which
    results in a lot of warnings from newer g++.
  * Added support for reading alpha channel in BMP format.
  * Fixed help viewer bug whereby the splitter sash in wxHtmlHelpWindow could
    go underneath the left-hand pane, permanently, after resizing the
    help window.
  * Fixed wxHTML default font size for printing to be 12pt regardless of the
    platform, instead of depending on GUI toolkit's screen configuration.
  * Support wxDP_ALLOWNONE style in generic wxDatePickerCtrl version.
  * Set wxKeyEvent::m_uniChar correctly in the events generated by generic
    wxListCtrl.
  * Fix changing size of merged cells in wxGrid.
  * Fixed wrapping bug in wxRichTextCtrl when there were images present;
    now sets the cursor to the next line after pressing Shift+Enter.
  * Fixed Cmd+Back, Cmd+Del word deletion behaviour in wxRichTextCtrl.
  * Fix crash when reading malformed PCX images.
  * Fix bug with wrong transparency in GIF animations.
  * Store palette information for XPM images in wxImage.
  * Fixed selection bugs and auto list numbering in wxRichTextCtrl.
  * Significantly optimize wxGrid::BlockToDeviceRect() for large grids.
  * Introduced new wxAuiToolBar class for better integration and look-and-feel.
  * Fix a crash in wxAuiFrameManager when Update() was called in between mouse-up
    and mouse-down events
  * wxAUI: added various NULL-ptr asserts.
  * Fixed problem with Floatable(false) not working in wxAuiFrameManager.
  * Fixed maximize bug in wxAUI.
  * Allow period in link anchors in wxHTML.
  * Fixed memory corruption in wxHTML when parsing "&;" in the markup.
  * Fixed event type in EVT_GRID_CMD_COL_MOVE and EVT_GRID_COL_MOVE.
  * wxGrid doesn't steal focus when hiding editor any more.
  * MIME types reading fixed when running under GNOME, reading .desktop
    files and also the default application list.
  * Added filesys.no-mimetypesmanager system option so that applications that
    must load an XRC file at program startup don't have to incur the
    mime types manager initialization penalty.
  * Fixed masking of disabled bitmaps in wxMenuItem and wxStaticBitmap.
  * Fixed generation of events for an initially empty wxDirPickerCtrl.
  * Fixed detection of Meta key state so that NumLock isn't misdetected
    as Meta (requires GTK+ 2.10).
  * Fix changing font/colour of label in buttons with images.
- Make funtion return a value.
* Wed Sep  3 2008 sbrabec@suse.cz
- Updated to version 2.8.8.1:
  * many API-compatible fixes and improvements, see
    docs/changes.txt for complete list
* Mon Sep  1 2008 sbrabec@suse.cz
- Dropped obsolete ODBC support (bnc#397044).
* Fri May  2 2008 sbrabec@suse.cz
- Don't unload libgnomevfs-2.so.0 on exit (bnc#380267).
- Removed obsolete configure options (bnc#380267#c7).
* Fri Mar 28 2008 sbrabec@suse.cz
- Updated to version 2.8.7.1:
  * many API-compatible crash fixes, improvements and other fixes,
    see docs/changes.txt for complete list
* Tue Oct  2 2007 sbrabec@suse.cz
- Updated to version 2.8.6.0:
  * many API-compatible crash fixes, improvements and orger fixes,
    see docs/changes.txt for complete list
  * fixed bugs and inconsistencies in wxWidgets and wxPython
* Thu Sep 13 2007 prusnak@suse.cz
- corrected last patch (gtk_border_free.patch) [#294693]
* Wed Sep  5 2007 bwalle@suse.de
- fix crash on startup on x86_64 (#294693)
* Wed Aug 29 2007 prusnak@suse.cz
- pack non-unicode libraries as wxGTK-compat package (again)
- run ldconfig in post/postun scriptlets
* Wed May 23 2007 prusnak@suse.cz
- update to 2.8.4.0
  * changes are too numerous to list, see changes.txt for full list
- drop non-unicode libraries (not used anymore)
- cleaned spec file
* Mon Mar  5 2007 pth@suse.de
- Don't hardcode lib64 in .spec file.
- Replace contrib/samples/applet/monitors.c once again (see #203607).
* Thu Mar  1 2007 pth@suse.de
- Update to 2.8.1.1. Changes are too numerous to list, see
  changes.txt for a full list.
- fix use of uninitialised variables wxPython_int.h
- Correct spelling in README.unicode
* Mon Dec 11 2006 sbrabec@suse.cz
- Source code cleanup (#226403).
* Tue Sep  5 2006 sbrabec@suse.cz
- Repackaged without undistributable monitors.c (#203607).
* Mon Aug  7 2006 sbrabec@suse.cz
- Updated to version 2.6.3.3 (#162198):
  * Fixed crash when loading message catalogs in Unicode build.
  * Fixed crash in wxList code when building with wxUSE_STL=1
  * Spurious error message from wxLaunchDefaultBrowser fixed.
  * Compilation fixes for (more strict) g++ 4.1
  * Speed improvements to wxRegEx
  * Fix regerror and regfree name conficts
  * wxCondition::WaitTimeout() now returns correct value
  * Bug in wxLogStream::DoLogString in Unicode builds fixed
  * wxFileName now also looks for TMPDIR on Unix
  * Fixed occasional wxThread cleanup crash
  * wxImage::Copy() forgot the alpha channel
  * Fixed wxSocketBase::InterruptWait on wxBase
  * wxSocket::_Read continues reading from socket after exhausting
    pushback buffer
  * Fixed abort() on loading invalid PNG image
  * Added space after list item number in wxHTML
  * wxCalendarCtrl drawing, positioning and hit-testing fixes
  * More checking of image validity before loading into wxImage
  * Added double-buffering to wxVListBox and fixed scrolling
  * More than one filter allowed in in wxDocTemplate filter
  * Fixed infinite loop in tab traversal code with wxUSE_STL==1
  * In wxScrolledWindow:DoGetBestSize, no longer adds difference
    between client and total size
  * Fixed problem with zoom setting in print preview
  * Fixed problem with choice editor in wxGrid
  * Fixed problem trying to print from a preview
  * Polygon and line drawing speeded up if there is no scaling
  * Fixed problems with CJK input method (reverted)
  * Fixed wxNotebook::HitTest when the leftmost visible tab is not
    the actual first tab
  * Send wxSetCursorEvent
  * Fix RequestMore for idle events
  * Implement user dashes for PS and GNOME printing
  * Correct update region code
  * Change wxMimeTypesManager code to just read the MIME-types
  * Speed up reading MIME database
  * wxClipboard fixes
  * Support underlined fonts in wxTextCtrl
  * wxWindow and wxScrolledWindow now generate all scroll events
  * Implemented wxToggleButton
  * Fixed wxDb::DBMS() indicating DB2 dBase databases
  * Fixed buffer overflow problem in Unicode builds
- Fixed slash typo patch.
- Do not delete no more generated doslex.c.
* Mon Jul 17 2006 mkudlvasr@suse.cz
- fixed a problem in makefiles.in and configure.in. In many cases
  the variable top_builddir was not separated by a slash. This caused
  many 'file not found' errors.
* Fri Apr  7 2006 mmarek@suse.cz
- fix array subscript out of range in src/common/db.cpp
* Thu Mar  9 2006 bk@suse.de
- Add esound-devel to BuildRequires (was implicily by SDL-devel)
- Add explicit gcc-c++ to BuildRequires (was implicit by SDL-devel)
* Tue Feb 28 2006 jmatejek@suse.cz
- updated to reflect python changes due to #149809
* Wed Feb 22 2006 sbrabec@suse.cz
- Moved pywxrc to python-wxGTK (Andreas Hanke, #152573).
* Sun Feb 19 2006 aj@suse.de
- Reduce BuildRequires.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 sbrabec@suse.cz
- Package wxrc (#143258, Andreas Hanke).
- Updated README.unicode (#144090, Andreas Hanke).
- Moved bakefile to devel subpackage (#144094, Andreas Hanke).
* Mon Jan 16 2006 sbrabec@suse.cz
- Updated to version 2.6.2.1.
* Mon Sep 19 2005 sbrabec@suse.cz
- Force re-creating the old lex code in doslex.c.
* Fri Aug 19 2005 sbrabec@suse.cz
- Removed references to no more provided PangoRenderX calls.
* Mon Aug  1 2005 sbrabec@suse.cz
- Updated to version 2.6.1.0.
* Sat May 14 2005 schwab@suse.de
- Fix undefined operation.
* Wed Apr 27 2005 mcihar@suse.cz
- update to 2.6.0.0
* Fri Apr 15 2005 mcihar@suse.de
- build with system libtiff
- enabled SDL and sound support
* Wed Apr 13 2005 mcihar@suse.cz
- fix filelist
- fix build on 64-bit machines
* Tue Apr 12 2005 mcihar@suse.cz
- disable SDL support, it seems to be broken in this version
* Tue Apr 12 2005 mcihar@suse.cz
- update to 2.5.5.1
* Fri Feb  4 2005 tiwai@suse.de
- fixed the confliction of ATTRIBUTE_PRINTF* macros.
* Wed Dec 22 2004 mcihar@suse.cz
- fix python-wxGTK requires
* Fri Nov 19 2004 mcihar@suse.cz
- update to 2.5.3.1
* Wed Oct 20 2004 mcihar@suse.cz
- fixed file conflict between python-wxGTK and wxGTK-devel
* Fri Sep 17 2004 mcihar@suse.cz
- really build wxPython version against unicode wxGTK (bug #45539)
* Tue Aug 31 2004 mcihar@suse.cz
- update to 2.5.2.8
* Mon Aug 16 2004 mcihar@suse.cz
- update to 2.5.2.7
* Fri Jul 30 2004 mcihar@suse.cz
- also build non unicode libraries and ship them in wxGTK-compat package
  to allow compilation of application, that weren't written in respect
  to unicode possibility
* Wed Jun  2 2004 mcihar@suse.cz
- add missing wxPython licenses
* Thu Apr 22 2004 mcihar@suse.cz
- ${prefix} was intentional
* Wed Apr 21 2004 mcihar@suse.cz
- correct libdir on lib64
* Tue Apr 20 2004 mcihar@suse.cz
- solved conflict between wxGTK-devel and python-wxGTK
* Wed Apr 14 2004 mcihar@suse.cz
- moved sound_sdl-2.5.1.so from devel package
* Wed Apr 14 2004 mcihar@suse.cz
- build with -fPIC
- add libmspack support (enables access to MS HTML help files - *.chm)
* Tue Apr 13 2004 mcihar@suse.cz
- update to 2.5.1.5
- enable unicode support
- enabled build of contrib libraries
* Thu Mar 18 2004 mcihar@suse.cz
- make files in bin executable (bug #36331)
* Fri Mar  5 2004 mcihar@suse.cz
- little spec file cleanup, debug build can be enabled
* Wed Mar  3 2004 tiwai@suse.de
- fixed wxwin.m4 for the recent autoconf.
- moved wxwin.m4 to devel subpackage.
* Tue Jan 13 2004 mcihar@suse.cz
- enabled build with GTK 2
* Thu Oct 16 2003 mcihar@suse.cz
- do not build as root
- remove orig and rej files that should not be installed
* Wed Oct 15 2003 mcihar@suse.cz
- update to 2.4.2.4
* Fri Aug 29 2003 tiwai@suse.de
- fixed the segfault on 64bit architectures.
* Sat Aug 23 2003 ro@suse.de
- fix build on lib64
* Wed Aug 20 2003 mcihar@suse.cz
- now builds together with wxPython
- created patch for DESTDIR support
- now lives in /usr and not /usr/X11
- build all python bindings (fixes #26138 and #27349)
* Wed Jul 30 2003 adrian@suse.de
- update to version 2.4.1
- add %%run_ldconfig
* Tue May 13 2003 mmj@suse.de
- Package forgotten files
* Tue Mar  4 2003 mmj@suse.de
- Add patch to have wxFileConfigGroup::DeleteSubgroup() not seg-
  fault with pGroup == 0. Triggered by audacity but might affect
  other wxGTK programs. [#24401]
* Tue Feb 25 2003 hhetter@suse.de
- devel package requires gtk-devel (Bug Id#22479)
* Mon Feb 17 2003 hhetter@suse.de
- package gl-header files too ( Bug Id#23094 )
* Wed Jan 22 2003 meissner@suse.de
- Fixed for lib64 platforms.
* Tue Jan 14 2003 hhetter@suse.de
- updated to version 2.4.0
- updated documentation to 2.4.0 revision
- remove all outdated patches
* Tue Nov 12 2002 tcrhak@suse.cz
- fixed for bison 1.75: end rules with semicolons
* Mon Aug 12 2002 garloff@suse.de
- Fix multiple delete[] in wxHtmlTagsModule::OnExit().
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuild
* Wed May  1 2002 kukuk@suse.de
- Remove superfluous libmpeg from neededforbuild
* Fri Apr 26 2002 coolo@suse.de
- use %%_libdir
* Mon Apr 15 2002 tiwai@suse.de
- fixed build with gcc 3.1.
* Tue Feb 19 2002 hhetter@suse.de
- applied the real patch for the wxgtk-mutex performance problem
* Fri Feb 15 2002 hhetter@suse.de
- configure with --enable-std_iostreams for better support
  for C++ sources using C++ iostreams
- apply patch to fix perfomance problem with multithreaded apps
  (accepted and already in the wxGTK CVS)
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Thu Jan 24 2002 tiwai@suse.de
- updated to version 2.2.9.
- fixed neededforbuild for libwx_gtk_gl.
- added locale files to filelist.
- added --enable-soname to ensure the correct linking.
- clean up the spec file.
* Mon May  7 2001 mfabian@suse.de
- bzip2 source
* Fri Mar 30 2001 pthomas@suse.de
- Update to 2.2.6
- Renamed to wxGTK
- Split off devel package.
- Build the OpenGl add-on lib.
- Install sample code in docdir.
- Change Makefiles to use DESTDIR.
- Include both HTML and PDF Versions of the manuals.
- Eliminate warnings in C++ code.
- Build with -W -Wall -Wstrict-prototypes -Wpointer-aritth
* Fri Jan 26 2001 hhetter@suse.de
- Update to 2.2.4
* Sat Dec  9 2000 mfabian@suse.de
- Add /usr/X11R6/bin/wxgtk-config to filelist
* Sun Nov  5 2000 ro@suse.de
- fixed neededforbuild
* Fri Jun  9 2000 ro@suse.de
- up to 2.1.16
* Mon Feb 21 2000 uli@suse.de
- now builds with RPM_OPT_FLAGS
* Mon Feb 21 2000 ro@suse.de
- update to 2.1.13
- use suse_update_config macro
- patch to compile with newest gtk
* Fri Jan 14 2000 freitag@suse.de
- update to 2.1.12, URL, doc in seperate tarball
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Aug 19 1999 kukuk@suse.de
- Add /usr/X11R6/bin/wx-config to filelist
* Tue Jul 13 1999 bs@suse.de
- use gtk and glib instead of gtkn and glibn
* Mon May 31 1999 ray@suse.de
- new package
